@@ -9,8 +9,6 @@ should normally not use them directly but rather use the high-level wrapper
 .. _Git: http://git-scm.com/
 
 """
-from __future__ import print_function
-
 import os
 
 from fabric.api import run, sudo, hide
@@ -325,7 +323,7 @@ class GitCheckerSatchel(Satchel):
 
     def record_manifest(self):
         self.check()
-        return super(GitCheckerSatchel, self).record_manifest()
+        return super().record_manifest()
 
     @task
     def configure(self):
@@ -377,7 +375,7 @@ class GitTrackerSatchel(Satchel):
         Called after a deployment to record any data necessary to detect changes
         for a future deployment.
         """
-        manifest = super(GitTrackerSatchel, self).record_manifest()
+        manifest = super().record_manifest()
         manifest[CURRENT_COMMIT] = self.get_current_commit()
         return manifest
 
